@@ -2,6 +2,7 @@
 from __future__ import absolute_import
 from django.utils.encoding import smart_str
 from geopy import geocoders
+from geopy.geocoders.base import GeocoderResultError
 
 class Error(Exception):
     pass
@@ -16,5 +17,5 @@ def google_v3(address):
         g = geocoders.GoogleV3()
         address = smart_str(address)
         return g.geocode(address, exactly_one=False)[0]
-    except (UnboundLocalError, ValueError, geocoders.google.GQueryError) as e:
+    except (UnboundLocalError, ValueError, GeocoderResultError) as e:
         raise Error(e)
